@@ -1,16 +1,21 @@
 package compress
 
 import (
+	"archive/tar"
+	"archive/zip"
 	"compress/gzip"
+	"context"
 	"fmt"
 	"io/ioutil"
 	"os"
 	"strings"
 	"testing"
 
+	"github.com/dsnet/compress/bzip2"
+	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
+	"github.com/hashicorp/packer-plugin-sdk/template"
 	"github.com/hashicorp/packer/builder/file"
-	"github.com/hashicorp/packer/packer"
-	"github.com/hashicorp/packer/template"
+	"github.com/pierrec/lz4"
 )
 
 func TestDetectFilename(t *testing.T) {
@@ -57,73 +62,6 @@ func TestDetectFilename(t *testing.T) {
 
 const expectedFileContents = "Hello world!"
 
-func TestSimpleCompress(t *testing.T) {
-	const config = `
-	{
-	    "post-processors": [
-	        {
-	            "type": "compress",
-	            "output": "package.tar.gz"
-	        }
-	    ]
-	}
-	`
-	artifact := testArchive(t, config)
-	defer artifact.Destroy()
-
-	fi, err := os.Stat("package.tar.gz")
-	if err != nil {
-		t.Errorf("Unable to read archive: %s", err)
-	}
-	if fi.IsDir() {
-		t.Error("Archive should not be a directory")
-	}
-}
-
-func TestZipArchive(t *testing.T) {
-	const config = `
-	{
-	    "post-processors": [
-	        {
-	            "type": "compress",
-	            "output": "package.zip"
-	        }
-	    ]
-	}
-	`
-
-	artifact := testArchive(t, config)
-	defer artifact.Destroy()
-
-	// Verify things look good
-	_, err := os.Stat("package.zip")
-	if err != nil {
-		t.Errorf("Unable to read archive: %s", err)
-	}
-}
-
-func TestTarArchive(t *testing.T) {
-	const config = `
-	{
-	    "post-processors": [
-	        {
-	            "type": "compress",
-	            "output": "package.tar"
-	        }
-	    ]
-	}
-	`
-
-	artifact := testArchive(t, config)
-	defer artifact.Destroy()
-
-	// Verify things look good
-	_, err := os.Stat("package.tar")
-	if err != nil {
-		t.Errorf("Unable to read archive: %s", err)
-	}
-}
-
 func TestCompressOptions(t *testing.T) {
 	const config = `
 	{
@@ -183,10 +121,9 @@ func TestCompressInterpolation(t *testing.T) {
 
 // Test Helpers
 
-func setup(t *testing.T) (packer.Ui, packer.Artifact, error) {
+func setup(t *testing.T) (packersdk.Ui, packersdk.Artifact, error) {
 	// Create fake UI and Cache
-	ui := packer.TestUi(t)
-	cache := &packer.FileCache{CacheDir: os.TempDir()}
+	ui := packersdk.TestUi(t)
 
 	// Create config for file builder
 	const fileConfig = `{"builders":[{"type":"file","target":"package.txt","content":"Hello world!"}]}`
@@ -197,7 +134,7 @@ func setup(t *testing.T) (packer.Ui, packer.Artifact, error) {
 
 	// Prepare the file builder
 	builder := file.Builder{}
-	warnings, err := builder.Prepare(tpl.Builders["file"].Config)
+	_, warnings, err := builder.Prepare(tpl.Builders["file"].Config)
 	if len(warnings) > 0 {
 		for _, warn := range warnings {
 			return nil, nil, fmt.Errorf("Configuration warning: %s", warn)
@@ -208,7 +145,7 @@ func setup(t *testing.T) (packer.Ui, packer.Artifact, error) {
 	}
 
 	// Run the file builder
-	artifact, err := builder.Run(ui, nil, cache)
+	artifact, err := builder.Run(context.Background(), ui, nil)
 	if err != nil {
 		return nil, nil, fmt.Errorf("Failed to build artifact: %s", err)
 	}
@@ -216,7 +153,7 @@ func setup(t *testing.T) (packer.Ui, packer.Artifact, error) {
 	return ui, artifact, err
 }
 
-func testArchive(t *testing.T, config string) packer.Artifact {
+func testArchive(t *testing.T, config string) packersdk.Artifact {
 	ui, artifact, err := setup(t)
 	if err != nil {
 		t.Fatalf("Error bootstrapping test: %s", err)
@@ -239,10 +176,112 @@ func testArchive(t *testing.T, config string) packer.Artifact {
 	compressor.config.PackerBuildName = "vanilla"
 	compressor.config.PackerBuilderType = "file"
 
-	artifactOut, _, err := compressor.PostProcess(ui, artifact)
+	artifactOut, _, _, err := compressor.PostProcess(context.Background(), ui, artifact)
 	if err != nil {
 		t.Fatalf("Failed to compress artifact: %s", err)
 	}
 
 	return artifactOut
 }
+
+func TestArchive(t *testing.T) {
+	tc := map[string]func(*os.File) ([]byte, error){
+		"bzip2": func(archive *os.File) ([]byte, error) {
+			bzipReader, err := bzip2.NewReader(archive, nil)
+			if err != nil {
+				return nil, err
+			}
+			return ioutil.ReadAll(bzipReader)
+		},
+		"zip": func(archive *os.File) ([]byte, error) {
+			fi, _ := archive.Stat()
+			zipReader, err := zip.NewReader(archive, fi.Size())
+			if err != nil {
+				return nil, err
+			}
+			ctt, err := zipReader.File[0].Open()
+			if err != nil {
+				return nil, err
+			}
+			return ioutil.ReadAll(ctt)
+		},
+		"tar": func(archive *os.File) ([]byte, error) {
+			tarReader := tar.NewReader(archive)
+			_, err := tarReader.Next()
+			if err != nil {
+				return nil, err
+			}
+			return ioutil.ReadAll(tarReader)
+		},
+		"tar.gz": func(archive *os.File) ([]byte, error) {
+			gzipReader, err := gzip.NewReader(archive)
+			if err != nil {
+				return nil, err
+			}
+			tarReader := tar.NewReader(gzipReader)
+			_, err = tarReader.Next()
+			if err != nil {
+				return nil, err
+			}
+			return ioutil.ReadAll(tarReader)
+		},
+		"gz": func(archive *os.File) ([]byte, error) {
+			gzipReader, _ := gzip.NewReader(archive)
+			return ioutil.ReadAll(gzipReader)
+		},
+		"lz4": func(archive *os.File) ([]byte, error) {
+			lz4Reader := lz4.NewReader(archive)
+			return ioutil.ReadAll(lz4Reader)
+		},
+	}
+
+	for format, unzip := range tc {
+		t.Run(format, func(t *testing.T) {
+			config := fmt.Sprintf(`
+		{
+			"post-processors": [
+				{
+					"type": "compress",
+					"output": "package.%s"
+				}
+			]
+		}
+		`, format)
+
+			artifact := testArchive(t, config)
+			defer func() {
+				err := artifact.Destroy()
+				if err != nil {
+					t.Fatal(err)
+				}
+			}()
+
+			filename := fmt.Sprintf("package.%s", format)
+			// Verify things look good
+			_, err := os.Stat(filename)
+			if err != nil {
+				t.Errorf("Unable to read archive: %s", err)
+			}
+
+			archive, err := os.Open(filename)
+			if err != nil {
+				t.Fatal(err)
+			}
+			defer func() {
+				err := archive.Close()
+				if err != nil {
+					t.Fatal(err)
+				}
+			}()
+
+			found, err := unzip(archive)
+			if err != nil {
+				t.Fatal(err)
+			}
+			if string(found) != expectedFileContents {
+				t.Errorf("Expected:\n%s\nFound:\n%s\n", expectedFileContents, string(found))
+			}
+		})
+	}
+
+}
